@@ -2,7 +2,7 @@
 import logging
 import re
 import warnings
-from typing import Any, Callable, Iterable, Optional, Pattern, Tuple, Union, cast
+from typing import TYPE_CHECKING, Any, Callable, Iterable, Optional, Pattern, Tuple, Union, cast
 
 import pyramid.config
 import pyramid.config.settings
@@ -12,9 +12,16 @@ import sqlalchemy.orm
 import transaction
 import zope.sqlalchemy
 from sqlalchemy import engine_from_config
-from sqlalchemy.orm import sessionmaker
 from zope.sqlalchemy import register
 
+if TYPE_CHECKING:
+    scoped_session = sqlalchemy.orm.scoped_session[sqlalchemy.orm.Session]
+    sessionmaker = sqlalchemy.orm.sessionmaker[sqlalchemy.orm.Session]
+else:
+    scoped_session = sqlalchemy.orm.scoped_session
+    sessionmaker = sqlalchemy.orm.sessionmaker
+
+
 LOG = logging.getLogger(__name__)
 RE_COMPILE: Callable[[str], Pattern[str]] = re.compile
 
@@ -35,7 +42,7 @@ def setup_session(
     force_master: Optional[Iterable[str]] = None,
     force_slave: Optional[Iterable[str]] = None,
 ) -> Tuple[
-    Union[sqlalchemy.orm.Session, sqlalchemy.orm.scoped_session[sqlalchemy.orm.Session]],
+    Union[sqlalchemy.orm.Session, scoped_session],
     sqlalchemy.engine.Engine,
     sqlalchemy.engine.Engine,
 ]:
@@ -95,7 +102,7 @@ def create_session(
     force_master: Optional[Iterable[str]] = None,
     force_slave: Optional[Iterable[str]] = None,
     **engine_config: Any,
-) -> Union[sqlalchemy.orm.Session, sqlalchemy.orm.scoped_session[sqlalchemy.orm.Session]]:
+) -> Union[sqlalchemy.orm.Session, scoped_session]:
     """
     Create a SQLAlchemy session.
 
@@ -147,7 +154,7 @@ def create_session(
 def _add_tween(
     config: pyramid.config.Configurator,
     name: str,
-    db_session: sqlalchemy.orm.scoped_session[sqlalchemy.orm.Session],
+    db_session: scoped_session,
     force_master: Optional[Iterable[str]],
     force_slave: Optional[Iterable[str]],
 ) -> None:
@@ -201,7 +208,7 @@ def _add_tween(
     config.add_tween("c2cwsgiutils.db.tweens." + name, over="pyramid_tm.tm_tween_factory")
 
 
-class SessionFactory(sessionmaker[sqlalchemy.orm.Session]):  # pylint: disable=unsubscriptable-object
+class SessionFactory(sessionmaker):
     """The custom session factory that manage the read only and read write sessions."""
 
     def __init__(
@@ -226,7 +233,7 @@ class SessionFactory(sessionmaker[sqlalchemy.orm.Session]):  # pylint: disable=u
 
     def __call__(  # type: ignore
         self, request: Optional[pyramid.request.Request], readwrite: Optional[bool] = None, **local_kw: Any
-    ) -> sqlalchemy.orm.scoped_session[sqlalchemy.orm.Session]:
+    ) -> scoped_session:
         if readwrite is not None:
             if readwrite and not force_readonly:
                 LOG.debug("Using %s database", self.rw_engine.c2c_name)  # type: ignore
@@ -262,7 +269,7 @@ def get_engine(
 
 def get_session_factory(
     engine: sqlalchemy.engine.Engine,
-) -> sessionmaker[sqlalchemy.orm.Session]:  # pylint: disable=unsubscriptable-object
+) -> sessionmaker:
     """Get the session factory from the engine."""
     factory = sessionmaker()
     factory.configure(bind=engine)
@@ -270,7 +277,7 @@ def get_session_factory(
 
 
 def get_tm_session(
-    session_factory: sessionmaker[sqlalchemy.orm.Session],  # pylint: disable=unsubscriptable-object
+    session_factory: sessionmaker,
     transaction_manager: transaction.TransactionManager,
 ) -> sqlalchemy.orm.Session:
     """
@@ -338,7 +345,7 @@ def get_tm_session_pyramid(
     session_factory: SessionFactory,
     transaction_manager: transaction.TransactionManager,
     request: pyramid.request.Request,
-) -> sqlalchemy.orm.scoped_session[sqlalchemy.orm.Session]:
+) -> scoped_session:
     """
     Get a ``sqlalchemy.orm.Session`` instance backed by a transaction.
 
